<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name></name>
    <message>
        <source></source>
        <translation>Project-Id-Version: GPSBabel command line program
POT-Creation-Date: 2005-11-19 01:14
PO-Revision-Date: 2008-04-26 21:18+0100
Last-Translator: Michele Locati &lt;mlocati@tiscali.it&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=utf-8
Content-Transfer-Encoding: 8bit
X-Generator: dxgettext 1.2.1
Language-Team:  &lt;mlocati@tiscali.it&gt;
X-Poedit-SourceCharset: iso-8859-1
X-Poedit-Language: Italian
X-Poedit-Country: ITALY
</translation>
    </message>
    <message>
        <source>(integer sec or &apos;auto&apos;) Barograph to GPS time diff</source>
        <translation type="obsolete">(sec interi o &apos;auto&apos;) Differenza temporale tra barografo e GPS</translation>
    </message>
    <message>
        <source>(USR input) Break segments into separate tracks</source>
        <translation type="obsolete">Ingresso USR: suddividi i segmenti in tracce separate</translation>
    </message>
    <message>
        <source>(USR output) Merge into one segmented track</source>
        <translation type="obsolete">Uscita USR: unisci in una traccia segmentata</translation>
    </message>
    <message>
        <source>Ad-hoc closed icon name</source>
        <translation type="obsolete">Nome ad-hoc icona chiusa</translation>
    </message>
    <message>
        <source>Ad-hoc open icon name</source>
        <translation type="obsolete">Nome ad-hoc icona aperta</translation>
    </message>
    <message>
        <source>After output job done sleep n second(s)</source>
        <translation type="obsolete">Attendi n secondi dopo il termine dell&apos;elaborazione</translation>
    </message>
    <message>
        <source>Allow whitespace synth. shortnames</source>
        <translation type="obsolete">Permetti spazi nei nomi brevi sintetizzati</translation>
    </message>
    <message>
        <source>Altitudes are absolute and not clamped to ground</source>
        <translation type="obsolete">Le quote sono assolute e non relative al terreno</translation>
    </message>
    <message>
        <source>Append icon_descr to description</source>
        <translation type="obsolete">Aggiungi icon_descr alla descrizione</translation>
    </message>
    <message>
        <source>Base URL for link tag in output</source>
        <translation type="obsolete">Url di base per i tag link in uscita</translation>
    </message>
    <message>
        <source>Basename prepended to URL on output</source>
        <translation type="obsolete">Nome base anteposto all&apos;URL in uscita</translation>
    </message>
    <message>
        <source>Bitmap of categories</source>
        <translation type="obsolete">Bitmap delle categorie</translation>
    </message>
    <message>
        <source>Category name (Cache)</source>
        <translation type="obsolete">Nome della categoria (cache)</translation>
    </message>
    <message>
        <source>Category number to use for written waypoints</source>
        <translation type="obsolete">Numero categoria da usare per i punti d&apos;interesse scritti</translation>
    </message>
    <message>
        <source>Color for lines or mapnotes</source>
        <translation type="obsolete">Colore per le linee o le note della mappa</translation>
    </message>
    <message>
        <source>Command unit to power itself down</source>
        <translation type="obsolete">Chiedi al dispositivo di spegnersi</translation>
    </message>
    <message>
        <source>Complete date-free tracks with given date (YYYYMMDD).</source>
        <translation type="obsolete">Completa le tracce senza data con la data fornita (AAAAMMGG).</translation>
    </message>
    <message>
        <source>Create unique waypoint names (default = yes)</source>
        <translation type="obsolete">Crea punti d&apos;interesse con nomi univoci (predefinito: sì)</translation>
    </message>
    <message>
        <source>Create waypoints from geocache log entries</source>
        <translation type="obsolete">Crea punti d&apos;interesse dagli elementi nel registro geocache</translation>
    </message>
    <message>
        <source>Database name</source>
        <translation type="obsolete">Nome della banca dati</translation>
    </message>
    <message>
        <source>Database name (filename)</source>
        <translation type="obsolete">Nome della banca dati (nome file)</translation>
    </message>
    <message>
        <source>Datum (default=NAD27)</source>
        <translation type="obsolete">Datum (predefinito: NAD27)</translation>
    </message>
    <message>
        <source>Days after which points are considered old</source>
        <translation type="obsolete">Giorni dopo i quali i punti sono considerati vecchi</translation>
    </message>
    <message>
        <source>Decimal seconds to pause between groups of strings</source>
        <translation type="obsolete">Pausa (in decimi di secondo) tra gruppi di stringhe</translation>
    </message>
    <message>
        <source>Default category on output</source>
        <translation type="obsolete">Categoria predefinita in uscita</translation>
    </message>
    <message>
        <source>Default category on output (1..16)</source>
        <translation type="obsolete">Categoria predefinita in uscita (1... 16)</translation>
    </message>
    <message>
        <source>Default icon name</source>
        <translation type="obsolete">Nome dell&apos;icona predefinita</translation>
    </message>
    <message>
        <source>Default location</source>
        <translation type="obsolete">Posizione predefinita</translation>
    </message>
    <message>
        <source>Default proximity</source>
        <translation type="obsolete">Prossimità predefinita</translation>
    </message>
    <message>
        <source>Default speed</source>
        <translation type="obsolete">Velocità predefinita</translation>
    </message>
    <message>
        <source>Default speed for waypoints (knots/hr)</source>
        <translation type="obsolete">Velocità predefinita per i punti di interesse (nodi/ora)</translation>
    </message>
    <message>
        <source>Degrees output as &apos;ddd&apos;, &apos;dmm&apos;(default) or &apos;dms&apos;</source>
        <translation type="obsolete">Gradi in uscita come &apos;ggg&apos;, &apos;gmm&apos; (predefinito) o &apos;gms&apos;</translation>
    </message>
    <message>
        <source>Delete all routes</source>
        <translation type="obsolete">Cancella tutte le rotte</translation>
    </message>
    <message>
        <source>Delete all track points</source>
        <translation type="obsolete">Cancella tutti i punti traccia</translation>
    </message>
    <message>
        <source>Delete all waypoints</source>
        <translation type="obsolete">Cancella tutti i punti d&apos;interesse</translation>
    </message>
    <message>
        <source>Display labels on track and routepoints  (default = 1)</source>
        <translation type="obsolete">Mostra le etichette su tracce e punti rotta (predefinito: 1)</translation>
    </message>
    <message>
        <source>Distance unit [m=metric, s=statute]</source>
        <translation type="obsolete">Unità di lunghezza [m=metrico, s=statutario]</translation>
    </message>
    <message>
        <source>Do not add geocache data to description</source>
        <translation type="obsolete">Non aggiungere dati geocache alla descrizione</translation>
    </message>
    <message>
        <source>Do not add URLs to description</source>
        <translation type="obsolete">Non aggiungere url alla descrizione</translation>
    </message>
    <message>
        <source>Don&apos;t show gpi bitmap on device</source>
        <translation type="obsolete">Non mostrare la bitmap gpi sul dispositivo</translation>
    </message>
    <message>
        <source>Draw extrusion line from trackpoint to ground</source>
        <translation type="obsolete">Disegna linee estruse dai punti traccia al terreno</translation>
    </message>
    <message>
        <source>Drop route points that do not have an equivalent waypoint (hidden points)</source>
        <translation type="obsolete">Ometti i punti rotta che non hanno un punto di interesse equivalente (punti nascosti)</translation>
    </message>
    <message>
        <source>Enable alerts on speed or proximity distance</source>
        <translation type="obsolete">Abilita avvisi su velocità o prossimità</translation>
    </message>
    <message>
        <source>Encrypt hints using ROT13</source>
        <translation type="obsolete">Cripta le note usando ROT13</translation>
    </message>
    <message>
        <source>Encrypt hints with ROT13</source>
        <translation type="obsolete">Cripta le note con ROT13</translation>
    </message>
    <message>
        <source>Erase device data after download</source>
        <translation type="obsolete">Cancella i dati dal dispositivo dopo lo scaricamento</translation>
    </message>
    <message>
        <source>Export linestrings for tracks and routes</source>
        <translation type="obsolete">Esporta le linee stringa da tracce e rotte</translation>
    </message>
    <message>
        <source>Export placemarks for tracks and routes</source>
        <translation type="obsolete">Esporta segnaposti da tracce e rotte</translation>
    </message>
    <message>
        <source>Full path to XCSV style file</source>
        <translation type="obsolete">Percorso completo del file di stile XCSV</translation>
    </message>
    <message>
        <source>Generate # points</source>
        <translation type="obsolete">N° punti da creare</translation>
    </message>
    <message>
        <source>Generate file with lat/lon for centering map</source>
        <translation type="obsolete">Crea un file con lat/lon per centrare la mappa</translation>
    </message>
    <message>
        <source>Give points (waypoints/route points) a default radius (proximity)</source>
        <translation type="obsolete">Raggio predefinito (prossimità) dei punti (d&apos;interesse/delle rotte)</translation>
    </message>
    <message>
        <source>GPS datum (def. WGS 84)</source>
        <translation type="obsolete">Datum GPS (predefinito: WGS 84)</translation>
    </message>
    <message>
        <source>Height in pixels of map</source>
        <translation type="obsolete">Altezza della mappa, in pixel</translation>
    </message>
    <message>
        <source>Ignore event marker icons on read</source>
        <translation type="obsolete">Ignora le icone dei marcatori in fase di lettura</translation>
    </message>
    <message>
        <source>Include extended data for trackpoints (default = 1)</source>
        <translation type="obsolete">Includi dati estesi sui punti traccia (predefinito: 1)</translation>
    </message>
    <message>
        <source>Include groundspeak logs if present</source>
        <translation type="obsolete">Includi registri groundspeak (se presenti)</translation>
    </message>
    <message>
        <source>Include major turn points (with description) from calculated route</source>
        <translation type="obsolete">Includi i punti di svolta principali (con descrizione) dalla rotta calcolata</translation>
    </message>
    <message>
        <source>Include only via stations in route</source>
        <translation type="obsolete">Includi solo stazioni intermedie nella rotta</translation>
    </message>
    <message>
        <source>Include short name in bookmarks</source>
        <translation type="obsolete">Includi nomi brevi nei segnaposti</translation>
    </message>
    <message>
        <source>Index of name field in .dbf</source>
        <translation type="obsolete">Indice del campo nome del .dbf</translation>
    </message>
    <message>
        <source>Index of route (if more than one in source)</source>
        <translation type="obsolete">Indice della rotta (se nell&apos;origine ce nè più d&apos;una)</translation>
    </message>
    <message>
        <source>Index of route to write (if more than one in source)</source>
        <translation type="obsolete">Indice della rotta da scrivere (se nell&apos;origine ce nè più d&apos;una)</translation>
    </message>
    <message>
        <source>Index of route/track to write (if more than one in source)</source>
        <translation type="obsolete">Indice della rotta/traccia da scrivere (se nell&apos;origine ce nè più d&apos;una)</translation>
    </message>
    <message>
        <source>Index of track (if more than one in source)</source>
        <translation type="obsolete">Indice della traccia (se nell&apos;origine ce nè più d&apos;una)</translation>
    </message>
    <message>
        <source>Index of track to write (if more than one in source)</source>
        <translation type="obsolete">Indice della traccia da scrivere (se nell&apos;origine ce nè più d&apos;una)</translation>
    </message>
    <message>
        <source>Index of URL field in .dbf</source>
        <translation type="obsolete">Indice del campo url nel .dbf</translation>
    </message>
    <message>
        <source>Indicate direction of travel in track icons (default = 0)</source>
        <translation type="obsolete">Indica la direzione di viaggio nelle icone di traccia (predefinito: 0)</translation>
    </message>
    <message>
        <source>Infrastructure closed icon name</source>
        <translation type="obsolete">Nome icona per infrastrutture chiuse</translation>
    </message>
    <message>
        <source>Infrastructure open icon name</source>
        <translation type="obsolete">Nome icona per infrastrutture aperte</translation>
    </message>
    <message>
        <source>Keep turns if simplify filter is used</source>
        <translation type="obsolete">Mantieni le svolte se si usa il filtro di semplificazione</translation>
    </message>
    <message>
        <source>Length of generated shortnames</source>
        <translation type="obsolete">Lunghezza dei nomi brevi generati</translation>
    </message>
    <message>
        <source>Length of generated shortnames (default 16)</source>
        <translation type="obsolete">Lunghezza dei nomi brevi generati (predefinito: 16)</translation>
    </message>
    <message>
        <source>Line color, specified in hex AABBGGRR</source>
        <translation type="obsolete">Colore delle linee, indicato in esadecimale AABBVVRR</translation>
    </message>
    <message>
        <source>Make synth. shortnames unique</source>
        <translation type="obsolete">Crea nomi brevi sintetizzati univoci</translation>
    </message>
    <message>
        <source>MapSend version TRK file to generate (3,4)</source>
        <translation type="obsolete">Versione del file TRK di MapSend da generare (3, 4)</translation>
    </message>
    <message>
        <source>Margin for map.  Degrees or percentage</source>
        <translation type="obsolete">Margine della mappa. Gradi o percentuale</translation>
    </message>
    <message>
        <source>Marker type for new points</source>
        <translation type="obsolete">Tipo di marcatore per i punti nuovi</translation>
    </message>
    <message>
        <source>Marker type for old points</source>
        <translation type="obsolete">Tipo di marcatore per i punti vecchi</translation>
    </message>
    <message>
        <source>Marker type for unfound points</source>
        <translation type="obsolete">Tipo di marcatore per i punti non trovati</translation>
    </message>
    <message>
        <source>Max length of waypoint name to write</source>
        <translation type="obsolete">Lunghezza massima dei nomi dei punti d&apos;interesse da scrivere</translation>
    </message>
    <message>
        <source>Max number of comments to write (maxcmts=200)</source>
        <translation type="obsolete">Numero massimo di commenti da scrivere (maxcmts=200)</translation>
    </message>
    <message>
        <source>Max shortname length when used with -s</source>
        <translation type="obsolete">Lunghezza massima dei nomi brevi quando si usa -s</translation>
    </message>
    <message>
        <source>Max synthesized shortname length</source>
        <translation type="obsolete">Lunghezza massima dei nomi brevi sintetizzati</translation>
    </message>
    <message>
        <source>Merge output with existing file</source>
        <translation type="obsolete">Unisci la destinazione con un file esistente</translation>
    </message>
    <message>
        <source>MTK compatible CSV output file</source>
        <translation type="obsolete">File di destinazione CVS compatibile con MTK</translation>
    </message>
    <message>
        <source>Name of the &apos;unassigned&apos; category</source>
        <translation type="obsolete">Nome della categoria &apos;Non assegnato&apos;</translation>
    </message>
    <message>
        <source>New name for the route</source>
        <translation type="obsolete">Nuovo nome della rotta</translation>
    </message>
    <message>
        <source>No separator lines between waypoints</source>
        <translation type="obsolete">Nessuna linea di separazione tra punti d&apos;interesse</translation>
    </message>
    <message>
        <source>No whitespace in generated shortnames</source>
        <translation type="obsolete">Nessuno spazio nei nomi brevi generati</translation>
    </message>
    <message>
        <source>Non-stealth encrypted icon name</source>
        <translation type="obsolete">Nome dell&apos;icona non nascosta/codificata</translation>
    </message>
    <message>
        <source>Non-stealth non-encrypted icon name</source>
        <translation type="obsolete">Nome dell&apos;icona non nascosta/non codificata</translation>
    </message>
    <message>
        <source>Numeric value of bitrate (baud=4800)</source>
        <translation type="obsolete">Valore numerico del bitrate (baud=4800)</translation>
    </message>
    <message>
        <source>Omit Placer name</source>
        <translation type="obsolete">Ometti nome localizzatore</translation>
    </message>
    <message>
        <source>Only read turns; skip all other points</source>
        <translation type="obsolete">Leggi solo le svolte; tralascia tutti gli altri punti</translation>
    </message>
    <message>
        <source>Path to HTML style sheet</source>
        <translation type="obsolete">Percorso del foglio di stile html</translation>
    </message>
    <message>
        <source>Precision of coordinates</source>
        <translation type="obsolete">Precisione delle coordinate</translation>
    </message>
    <message>
        <source>Proximity distance</source>
        <translation type="obsolete">Distanza di prossimità</translation>
    </message>
    <message>
        <source>Radius for circles</source>
        <translation type="obsolete">Raggio dei cerchi</translation>
    </message>
    <message>
        <source>Radius of our big earth (default 6371000 meters)</source>
        <translation type="obsolete">Raggio della Terra (predefinito: 6371000 metri)</translation>
    </message>
    <message>
        <source>Read control points as waypoint/route/none</source>
        <translation type="obsolete">Leggi i punti di controllo come punti di interesse/rotte/nessuno</translation>
    </message>
    <message>
        <source>Read/Write date format (i.e. DDMMYYYY)</source>
        <translation type="obsolete">Formato data in lettura/scrittura (per es. DDMMYYYY)</translation>
    </message>
    <message>
        <source>Read/Write date format (i.e. yyyy/mm/dd)</source>
        <translation type="obsolete">Formato data in lettura/scrittura (per es. yyyy/mm/dd)</translation>
    </message>
    <message>
        <source>Read/write GPGGA sentences</source>
        <translation type="obsolete">Leggi/scrivi frasi GPGGA</translation>
    </message>
    <message>
        <source>Read/write GPGSA sentences</source>
        <translation type="obsolete">Leggi/scrivi frasi GPGSA</translation>
    </message>
    <message>
        <source>Read/write GPRMC sentences</source>
        <translation type="obsolete">Leggi/scrivi frasi GPRMC</translation>
    </message>
    <message>
        <source>Read/write GPVTG sentences</source>
        <translation type="obsolete">Leggi/scrivi frasi GPVTG</translation>
    </message>
    <message>
        <source>Read/Write time format (i.e. HH:mm:ss xx)</source>
        <translation type="obsolete">Formato ora in lettura/scrittura (per es. HH:mm:ss xx)</translation>
    </message>
    <message>
        <source>Retain at most this number of position points  (0 = unlimited)</source>
        <translation type="obsolete">Mantieni almeno questo numero di punti posizione (0 = illimitati)</translation>
    </message>
    <message>
        <source>Return current position as a waypoint</source>
        <translation type="obsolete">Ritorna la posizione corrente sotto forma di punto d&apos;interesse</translation>
    </message>
    <message>
        <source>Road type changes</source>
        <translation type="obsolete">Modifiche al tipo di strada</translation>
    </message>
    <message>
        <source>Set waypoint name to source filename.</source>
        <translation type="obsolete">Imposta il nome del punto di interesse col nome del file di origine</translation>
    </message>
    <message>
        <source>Shortname is MAC address</source>
        <translation type="obsolete">Il nome breve è un indirizzo MAC</translation>
    </message>
    <message>
        <source>Speed in bits per second of serial port (baud=4800)</source>
        <translation type="obsolete">Velocità in bit/secondo della porta seriale (baud=4800)</translation>
    </message>
    <message>
        <source>Split input into separate files</source>
        <translation type="obsolete">Suddividi l&apos;ingresso in più file separati</translation>
    </message>
    <message>
        <source>Split into multiple routes at turns</source>
        <translation type="obsolete">Suddividi in più rotte alle svolte</translation>
    </message>
    <message>
        <source>Starting seed of the internal number generator</source>
        <translation type="obsolete">Seme iniziale del generatore interno di numeri</translation>
    </message>
    <message>
        <source>Stealth encrypted icon name</source>
        <translation type="obsolete">Nome dell&apos;icona nascosta/codificata</translation>
    </message>
    <message>
        <source>Stealth non-encrypted icon name</source>
        <translation type="obsolete">Nome dell&apos;icona nascosta/non codificata</translation>
    </message>
    <message>
        <source>String to separate concatenated address fields (default=&quot;, &quot;)</source>
        <translation type="obsolete">Stringa per separare i campi indirizzo concatenati (predefinito: &quot;, &quot;)</translation>
    </message>
    <message>
        <source>Suppress labels on generated pins</source>
        <translation type="obsolete">Ometti le etichette sugli spilli generati</translation>
    </message>
    <message>
        <source>Suppress retired geocaches</source>
        <translation type="obsolete">Ometti i geocache obsoleti</translation>
    </message>
    <message>
        <source>Suppress separator lines between waypoints</source>
        <translation type="obsolete">Ometti le linee di separazione tra punti d&apos;interesse</translation>
    </message>
    <message>
        <source>Suppress use of handshaking in name of speed</source>
        <translation type="obsolete">Ometti l&apos;uso dell&apos;handshake per aumentare la velocità</translation>
    </message>
    <message>
        <source>Suppress whitespace in generated shortnames</source>
        <translation type="obsolete">Ometti gli spazi nei nomi brevi generati</translation>
    </message>
    <message>
        <source>Symbol to use for point data</source>
        <translation type="obsolete">Simbolo da usare per i punti</translation>
    </message>
    <message>
        <source>Sync GPS time to computer time</source>
        <translation type="obsolete">Sincronizza l&apos;ora del GPS con quella del computer</translation>
    </message>
    <message>
        <source>Synthesize track times</source>
        <translation type="obsolete">Sintetizza gli orari delle tracce</translation>
    </message>
    <message>
        <source>Target GPX version for output</source>
        <translation type="obsolete">Versione GPX del file di destinazione</translation>
    </message>
    <message>
        <source>Temperature unit [c=Celsius, f=Fahrenheit]</source>
        <translation type="obsolete">Unità di temperatura [c=Celsius, f=Fahrenheit]</translation>
    </message>
    <message>
        <source>The icon description is already the marker</source>
        <translation type="obsolete">La descrizione dell&apos;icona è già il segnaposto</translation>
    </message>
    <message>
        <source>Treat waypoints as icons on write</source>
        <translation type="obsolete">Considera i punti d&apos;interesse come icone in fase di scrittura</translation>
    </message>
    <message>
        <source>Type of .an1 file</source>
        <translation type="obsolete">Tipo del file .an1</translation>
    </message>
    <message>
        <source>Units for altitude (f)eet or (m)etres</source>
        <translation type="obsolete">Unità di misura della quota [m: metri, f: piedi]</translation>
    </message>
    <message>
        <source>Units used for names with @speed (&apos;s&apos;tatute or &apos;m&apos;etric)</source>
        <translation type="obsolete">Untià di misura per nomi con @speed [m: metrico, s: statutario]</translation>
    </message>
    <message>
        <source>Units used when writing comments (&apos;s&apos;tatute or &apos;m&apos;etric)</source>
        <translation type="obsolete">Unità da usare quando si scrivono i commenti [m: metrico, s: statutario]</translation>
    </message>
    <message>
        <source>UPPERCASE synth. shortnames</source>
        <translation type="obsolete">Nomi brevi sintetizzati in MAIUSCOLO</translation>
    </message>
    <message>
        <source>Use depth values on output (default is ignore)</source>
        <translation type="obsolete">Usa i valori di profondità nella destinazione (predefinito: ignora)</translation>
    </message>
    <message>
        <source>Use proximity values on output (default is ignore)</source>
        <translation type="obsolete">Usa i valori di prossimità nella destinazione (predefinito: ignora)</translation>
    </message>
    <message>
        <source>Use shortname instead of description</source>
        <translation type="obsolete">Usa il nome breve invece della descrizione</translation>
    </message>
    <message>
        <source>Use specified bitmap on output</source>
        <translation type="obsolete">Usa la bitmap specificata nella destinazione</translation>
    </message>
    <message>
        <source>Version of gdb file to generate (1..3)</source>
        <translation type="obsolete">Versione del file gdb da generare (1... 3)</translation>
    </message>
    <message>
        <source>Version of mapsource file to generate (3,4,5)</source>
        <translation type="obsolete">Versione del file MapSource da generare (3, 4, 5)</translation>
    </message>
    <message>
        <source>Waypoint background color</source>
        <translation type="obsolete">Colore di sfondo dei punti d&apos;interesse</translation>
    </message>
    <message>
        <source>Waypoint foreground color</source>
        <translation type="obsolete">Colore dei punti d&apos;interesse</translation>
    </message>
    <message>
        <source>Waypoint type</source>
        <translation type="obsolete">Tipo dei punti d&apos;interesse</translation>
    </message>
    <message>
        <source>Width in pixels of map</source>
        <translation type="obsolete">Larghezza della mappa, in pixel</translation>
    </message>
    <message>
        <source>Width of lines, in pixels</source>
        <translation type="obsolete">Larghezza delle linee, in pixel</translation>
    </message>
    <message>
        <source>Write additional node tag key/value pairs</source>
        <translation type="obsolete">Scrivi coppie addizionali di tag chiave/valore per i nodi</translation>
    </message>
    <message>
        <source>Write additional way tag key/value pairs</source>
        <translation type="obsolete">Scrivi coppie addizionali di tag chiave/valore per le vie</translation>
    </message>
    <message>
        <source>Write all tracks into one file</source>
        <translation type="obsolete">Scrivi tutte le tracce in un solo file</translation>
    </message>
    <message>
        <source>Write description to address field</source>
        <translation type="obsolete">Scrivi la descrizione nel campo indirizzo</translation>
    </message>
    <message>
        <source>Write each waypoint in a separate file</source>
        <translation type="obsolete">Scrivi ciascun punto d&apos;interesse in un file separato</translation>
    </message>
    <message>
        <source>Write notes to address field</source>
        <translation type="obsolete">Scrivi le note nel campo indirizzo</translation>
    </message>
    <message>
        <source>Write position to address field</source>
        <translation type="obsolete">Scrivi la posizione del campo indirizzo</translation>
    </message>
    <message>
        <source>Write position using this grid.</source>
        <translation type="obsolete">Scrivi la posizione usando questa griglia.</translation>
    </message>
    <message>
        <source>Write timestamps with offset x to UTC time</source>
        <translation type="obsolete">Scrivi date e ore con scostamento X rispetto al tempo UTC</translation>
    </message>
    <message>
        <source>Write tracks compatible with Carto Exploreur</source>
        <translation type="obsolete">Scrivi tracce compatibili con Carto Exploreur</translation>
    </message>
    <message>
        <source>Write tracks for Gisteq Phototracker</source>
        <translation type="obsolete">Scrivi tracce per Gisteq Phototracker</translation>
    </message>
    <message>
        <source>Zoom level to reduce points</source>
        <translation type="obsolete">Livello di zoom per ridurre i punti</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>About GPSBabel</source>
        <translation>Informazioni su GPSBabel</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$babelfeversion$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Copyright (C) 2009 Robert Lipe&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;GUI designed and contributed by  S. Khai Mong&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;LGPL Crystal Icons by Elvarado Coehlo&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;(Using backend $babelversion$)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$upgradetestmode$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;This program is free software; you can redistribute it and/or  modify it under the terms of the GNU General Public License as  published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$babelfeversion$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Copyright (C) 2009 Robert Lipe&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Interfaccia grafica disegnata e implementata da  S. Khai Mong&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;LGPL Crystal Icons di Alvarado Coehlo&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;(Uso backend $babelversion$)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$upgradetestmode$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;
Questo programma &amp;egrave; software libero; è possibile distribuirlo e/o modificarlo secondo i termini della GNU General Public License come  pubblicata dalla Free Software Foundation; sia la versione 2 della licenza, sia (a propria scelta) una versione successiva.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Questo programma &amp;egrave; distribuito nella speranza che sia utile, ma SENZA ALCUNA GARANZIA; senza neppure la garanzia implicita di COMMERCIABILIT&amp;Agrave; o IDONEIT&amp;Agrave; PER UNO SCOPO PARTICOLARE.  Vedere la GNU General Public License per ulteriori dettagli.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Si dovrebbe aver ricevuto una copia della GNU General Public License insieme a questo programma; in caso contrario, scrivere alla Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
</context>
<context>
    <name>AdvUi</name>
    <message>
        <source>Global Options</source>
        <translation>Opzioni generali</translation>
    </message>
    <message>
        <source>Create smart shortened names. </source>
        <translation>Crea nomi abbreviati intelligenti. </translation>
    </message>
    <message>
        <source>Synthesize short names</source>
        <translation>Sintetizza i nomi brevi</translation>
    </message>
    <message>
        <source>Convert character set encoding between input and output</source>
        <translation>Converti la codifica del set di caratteri tra sorgente e destinazione</translation>
    </message>
    <message>
        <source>Enable character set transformation</source>
        <translation>Abilita la trasformazione del set di caratteri</translation>
    </message>
    <message>
        <source>Preview in Google Maps</source>
        <translation>Anteprima in Google Maps</translation>
    </message>
    <message>
        <source>Debugging diagnostics.  
Higher number provides more deitaled diagnostics.</source>
        <translation>Diagnosi di debug.  
Un numero più alto fornisce un livello di diagnosi più dettagliato.</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <source>Debugging Diagnostics</source>
        <translation>Diagnosi di debug</translation>
    </message>
    <message>
        <source>Set all format input/output options to default values</source>
        <translation>Imposta tutte le opzioni di origine/destinazione ai valori predefiniti</translation>
    </message>
    <message>
        <source>Default Format Options</source>
        <translation>Opzioni predefinite dei formati</translation>
    </message>
</context>
<context>
    <name>FileDlgManager</name>
    <message>
        <source>Select input file</source>
        <translation>Seleziona il file di origine</translation>
    </message>
    <message>
        <source>Select output file</source>
        <translation>Seleziona il file di destinazione</translation>
    </message>
</context>
<context>
    <name>FilterDialog</name>
    <message>
        <source>Tracks</source>
        <translation>Tracce</translation>
    </message>
    <message>
        <source>Waypoints</source>
        <translation>Punti di interesse</translation>
    </message>
    <message>
        <source>Routes &amp; Tracks</source>
        <translation>Rotte e tracce</translation>
    </message>
    <message>
        <source>Miscellaneous</source>
        <translation>Varie</translation>
    </message>
    <message>
        <source>Are you sure you want to reset all filter options to default values?</source>
        <translation>Si è certi di voler reimpostare tutte le opzioni dei filtri ai valori predefiniti?</translation>
    </message>
</context>
<context>
    <name>FilterDlg</name>
    <message>
        <source>Data Filters</source>
        <translation>Filtri di dati</translation>
    </message>
    <message>
        <source>Data filters process and transform the data between input and output files or devices. </source>
        <translation>I filtri di dati processano e trasformano i dati da file/dispositivi di origine e destinazione.</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reimposta</translation>
    </message>
</context>
<context>
    <name>GMapDialog</name>
    <message>
        <source>meters</source>
        <translation>metri</translation>
    </message>
    <message>
        <source>feet</source>
        <translation>piede</translation>
    </message>
    <message>
        <source>miles</source>
        <translation>miglia</translation>
    </message>
    <message>
        <source>Length: %1 %2
  %3 %4</source>
        <translation>Lunghezza: %1 %2
  %3 %4</translation>
    </message>
    <message>
        <source>Lat: %1</source>
        <translation>Lat: %1</translation>
    </message>
    <message>
        <source>Lng: %1</source>
        <translation>Lng: %1</translation>
    </message>
    <message>
        <source>Desc: %1</source>
        <translation>Desc: %1</translation>
    </message>
    <message>
        <source>Cmt: %1</source>
        <translation>Cmt: %1</translation>
    </message>
    <message>
        <source>Ele: %1</source>
        <translation>Alt: %1</translation>
    </message>
    <message>
        <source>Start: %1</source>
        <translation>Avvio: %1</translation>
    </message>
    <message>
        <source>Stop: %1</source>
        <translation>Stop: %1</translation>
    </message>
    <message>
        <source>Points: %1</source>
        <translation>Punti: %1</translation>
    </message>
    <message>
        <source>Waypoints</source>
        <translation>Punti di interesse</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Tracce</translation>
    </message>
    <message>
        <source>Routes</source>
        <translation>Rotte</translation>
    </message>
    <message>
        <source>Show All Waypoints</source>
        <translation>Mostra tutti i punti di interesse</translation>
    </message>
    <message>
        <source>Hide All Waypoints</source>
        <translation>Nascondi tutti i punti di interesse</translation>
    </message>
    <message>
        <source>Expand All</source>
        <translation>Espandi tutto</translation>
    </message>
    <message>
        <source>Collapse All</source>
        <translation>Contrai tutto</translation>
    </message>
    <message>
        <source>Show All Routes</source>
        <translation>Mostra tutte le rotte</translation>
    </message>
    <message>
        <source>Hide All Routes</source>
        <translation>Nascondi tutte le rotte</translation>
    </message>
    <message>
        <source>Show All Tracks</source>
        <translation>Mostra tutte le tracce</translation>
    </message>
    <message>
        <source>Hide All Tracks</source>
        <translation>Nascondi tutte le tracce</translation>
    </message>
    <message>
        <source>Show Only This Waypoint</source>
        <translation>Mostra solo questo punto di interesse</translation>
    </message>
    <message>
        <source>Show Only This Track</source>
        <translation>Mostra solo questa traccia</translation>
    </message>
    <message>
        <source>Show Only This Route</source>
        <translation>Mostra solo questa rotta</translation>
    </message>
</context>
<context>
    <name>GMapDlg</name>
    <message>
        <source>Dialog</source>
        <translation>Finestra di dialogo</translation>
    </message>
    <message>
        <source>Copy to Clipboard</source>
        <translation>Copia negli appunti</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation>FinestraPrincipale</translation>
    </message>
    <message>
        <source>Input </source>
        <translation>Ingresso</translation>
    </message>
    <message>
        <source>If selected, input is from a file.</source>
        <translation>Se selezionato, l&apos;ingresso è da file.</translation>
    </message>
    <message>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <source>If selected, input is from a device or GPS unit</source>
        <translation>Se selezionato, l&apos;ingresso è da un dispositivo o da un&apos;unità GPS</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Input data format</source>
        <translation>Formato dei dati in ingresso</translation>
    </message>
    <message>
        <source>Character encoding of input</source>
        <translation>Codifica dei caratteri dell&apos;ingresso</translation>
    </message>
    <message>
        <source>Browse for one or more input files. </source>
        <translation>Sfoglia uno o più file d&apos;ingresso.</translation>
    </message>
    <message>
        <source>File Name(s)</source>
        <translation>Nome/i di file</translation>
    </message>
    <message>
        <source>Device Name:</source>
        <translation>Nome del dispositivo:</translation>
    </message>
    <message>
        <source>Name of port to which input device is connected</source>
        <translation>Nome della porta cui è connesso il dispositivo d&apos;ingresso</translation>
    </message>
    <message>
        <source>Options for the selected input format. </source>
        <translation>Opzioni per il formato d&apos;ingresso selezionato.</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Translation Options</source>
        <translation>Opzioni di traduzione</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>If selected, translate waypoints.</source>
        <translation>Se selezionato, traduce i punti di interesse.</translation>
    </message>
    <message>
        <source>Waypoints</source>
        <translation>Punti di interesse</translation>
    </message>
    <message>
        <source>If selected, translate routes.</source>
        <translation>Se selezionato, traduce le rotte.</translation>
    </message>
    <message>
        <source>Routes</source>
        <translation>Rotte</translation>
    </message>
    <message>
        <source>If selected, translate tracks.</source>
        <translation>Se selezionato, traduce le tracce.</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Tracce</translation>
    </message>
    <message>
        <source>Data Filters between input and output</source>
        <translation>Filtri di dati tra sorgente e destinazione</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtri</translation>
    </message>
    <message>
        <source>More translation options. </source>
        <translation>Altre opzioni di traduzione.</translation>
    </message>
    <message>
        <source>More Options</source>
        <translation>Altre opzioni</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Destinazione</translation>
    </message>
    <message>
        <source>If selected, output is to a file. </source>
        <translation>Se selezionato, la destinazione è un file.</translation>
    </message>
    <message>
        <source>If selected, output is to a device or GPS unit</source>
        <translation>Se selezionato, la destinazione è un dispositivo o un&apos;unità GPS</translation>
    </message>
    <message>
        <source>Output data format.</source>
        <translation>Formato dei dati di destinazione.</translation>
    </message>
    <message>
        <source>Character encoding of output</source>
        <translation>Codifica dei caratteri della destinazione</translation>
    </message>
    <message>
        <source>Browse for an output file name. </source>
        <translation>Seleziona il nome del file di destinazione.</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Nome del file</translation>
    </message>
    <message>
        <source>Name of port to which output device is connected</source>
        <translation>Nome della porta cui è connesso il dispositivo di destinazione</translation>
    </message>
    <message>
        <source>Options for the selected output format. </source>
        <translation>Opzioni per il formato di destinazione selezionato.</translation>
    </message>
    <message>
        <source>Output of GPSBabel translation process. </source>
        <translation>Risultato del processo di traduzione di GPSBabel.</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>GPSBabel Help</source>
        <translation>Aiuto di GPSBabel</translation>
    </message>
    <message>
        <source>About GPSBabel</source>
        <translation>Informazioni su GPSBabel</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Preferenze...</translation>
    </message>
    <message>
        <source>default</source>
        <translation>predefinite</translation>
    </message>
    <message>
        <source>Select one or more input files</source>
        <translation>Selezionare uno o più file in ingresso</translation>
    </message>
    <message>
        <source>Output File Name</source>
        <translation>Nome del file in uscita</translation>
    </message>
    <message>
        <source>Error reading format configuration.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH

This program cannot continue.</source>
        <translation>Errore durante la lettura del formato della configurazione.  Verificare che il programma backend &quot;gpsbabel&quot; sia installato correttamente e che sia nel percorso corrente (variabile PATH)

Questo programma non può proseguire.</translation>
    </message>
    <message>
        <source>Some file/device formats were not found during initialization.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH

This program cannot continue.</source>
        <translation>Qualche formato di file/dispositivo non è stato trovato durante l&apos;inizializzazione.  Verifica che il programma di backend &quot;gpsbabel&quot; sia correttamente installato e che sia nel PATH corrente

Questo programma non può proseguire.</translation>
    </message>
    <message>
        <source>Input and output formats do not support %1</source>
        <translation>I formati di ingresso e di uscita non supportano %1</translation>
    </message>
    <message>
        <source>Input does not support %1; output format supports %2</source>
        <translation>L&apos;ingresso non supporta %1, il formato di destinazione supporta %2</translation>
    </message>
    <message>
        <source>Input format supports %1; output format does not support %2</source>
        <translation>Il formato in ingresso supporta %1, il formato di destinazione non supporta %2</translation>
    </message>
    <message>
        <source>Both input and output formats support %1</source>
        <translation>I formati di origine e di destinazione supportano %1</translation>
    </message>
    <message>
        <source>waypoints</source>
        <translation>punti di interesse</translation>
    </message>
    <message>
        <source>tracks</source>
        <translation>tracce</translation>
    </message>
    <message>
        <source>routes</source>
        <translation>rotte</translation>
    </message>
    <message>
        <source>There are no input options for format &quot;%1&quot;</source>
        <translation>Non ci sono opzioni in ingresso per il formato &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Options for %1</source>
        <translation>Opzioni per %1</translation>
    </message>
    <message>
        <source>There are no output options for format &quot;%1&quot;</source>
        <translation>Non ci sono opzioni in uscita per il formato &quot;%1&quot;</translation>
    </message>
    <message>
        <source>No valid waypoints/routes/tracks translation specified</source>
        <translation>Non è stato specificato alcun punto di interesse/rotta/traccia</translation>
    </message>
    <message>
        <source>No input file specified</source>
        <translation>Il file di origine non è stato specificato</translation>
    </message>
    <message>
        <source>No valid output specified</source>
        <translation>Non è stata specificata una destinazione valida</translation>
    </message>
    <message>
        <source>No output file specified</source>
        <translation>Il file di destinazione non è stato specificato</translation>
    </message>
    <message>
        <source>Process &quot;%1&quot; did not start</source>
        <translation>Il processo &quot;%1&quot; non è stato avviato</translation>
    </message>
    <message>
        <source>Process exited unsucessfully with code %1</source>
        <translation>Il processo è terminato con il codice di errorre %1</translation>
    </message>
    <message>
        <source>Translation successful</source>
        <translation>Traduzione terminata con successo</translation>
    </message>
    <message>
        <source>Error running gpsbabel: %1
</source>
        <translation>Errore durante l&apos;esecuzione di gpsbabel: %1
</translation>
    </message>
    <message>
        <source>Are you sure you want to reset all format options to default values?</source>
        <translation>Si è certi di voler reimpostare tutte le opzioni dei formati ai valori predefiniti?</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Informazioni su %1</translation>
    </message>
    <message>
        <source>One or more data filters are active</source>
        <translation>È attivo uno o più filtri di dati</translation>
    </message>
    <message>
        <source>No data filters are active</source>
        <translation>Nessun filtro di dati è attivo</translation>
    </message>
    <message>
        <source>Check for Upgrade</source>
        <translation>Verifica aggiornamenti</translation>
    </message>
</context>
<context>
    <name>Map</name>
    <message>
        <source>Missing &quot;gmapbase.html&quot; file.  Check installation</source>
        <translation>Il file &quot;gmapbase.html&quot; manca. Verifica l&apos;installazione</translation>
    </message>
    <message>
        <source>Failed to load Google maps base page</source>
        <translation>Non è stato possibile caricare la pagina di base delle mappe di Google</translation>
    </message>
</context>
<context>
    <name>MiscFltWidget</name>
    <message>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <source>Misc. Filters</source>
        <translation>Filtri vari</translation>
    </message>
    <message>
        <source>Nuke (Remove) Data Types</source>
        <translation>Rimuovi tipi di dati</translation>
    </message>
    <message>
        <source>Routes</source>
        <translation>Rotte</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Tracce</translation>
    </message>
    <message>
        <source>Waypoints</source>
        <translation>Punti di interesse</translation>
    </message>
    <message>
        <source>Convert routes, waypoints and tracks to different types.</source>
        <translation>Converti rotte, punti di interesse e tracce in tipi differenti.</translation>
    </message>
    <message>
        <source>This filter can be used to convert GPS data between different data types.

Some GPS data formats support only some subset of waypoints, tracks, and routes. The transform filter allows you to convert between these types. For example, it can be used to convert a pile of waypoints (such as those from a CSV file) into a track or vice versa. </source>
        <translation>Questo filtro può essere usato per convertire dati GPS tra diversi tipi di dati.

Qualche formato di dati del GPS supporta solo un sottoinsieme di punti di interesse, tracce e rotte. Il filtro di trasformazione permette la conversione tra questi tipi. Per esempio, può essere usato per convertire un insieme di punti di interesse (per esempio da un file CSV) in una traccia (o viceversa).</translation>
    </message>
    <message>
        <source>Transform</source>
        <translation>Trasforma</translation>
    </message>
    <message>
        <source>Type of transformation. </source>
        <translation>Tipo di trasformazione.</translation>
    </message>
    <message>
        <source>Delete original data after transform to prevent duplicated data. </source>
        <translation>Elimina i dati originali dopo la trasformazione per evitare dati duplicati.</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Swap Longitude and Latitudes for badly formatted data formats.</source>
        <translation>Scambia longitudine e latitudine per i formati di data malformati.</translation>
    </message>
    <message>
        <source>Simple filter to swap the coordinate values (latitude and longitude) of all points. This can be helpful for wrong defined/coded data. Or if you think, you can use one of our xcsv formats, but latitude and longitude are in opposite order. </source>
        <translation>Semplice filtro per scambiare i valori delle coordinate (latitudine e longitudine) di tutti i punti. Può essere utile nel caso di dati malformati. O, se preferisci, puoi usare uno dei nostri formati xcsv, ma latitudine e longitudine sono scambiate.</translation>
    </message>
    <message>
        <source>Swap Coordinates</source>
        <translation>Scambia le coordinate</translation>
    </message>
</context>
<context>
    <name>OptionsDlg</name>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <source>GPSBabel Preferences</source>
        <translation>Preferenze di GPSBabel</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generali</translation>
    </message>
    <message>
        <source>Check for newer version on start.</source>
        <translation>Verifica nuove versioni all&apos;avvio.</translation>
    </message>
    <message>
        <source>Anonymously report usage data.</source>
        <translation>Trasmetti informazioni anonime sull&apos;utilizzo.</translation>
    </message>
    <message>
        <source>Formats</source>
        <translation>Formati</translation>
    </message>
    <message>
        <source>Enabled Formats</source>
        <translation>Formati abilitati</translation>
    </message>
    <message>
        <source>Enable All</source>
        <translation>Abilita tutti</translation>
    </message>
    <message>
        <source>Disable All</source>
        <translation>Disabilita tutti</translation>
    </message>
</context>
<context>
    <name>ProcessWaitDialog</name>
    <message>
        <source>Process failed to start</source>
        <translation>Si è verificato un errore durante l&apos;avvio del processo</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Il processo si è interrotto</translation>
    </message>
    <message>
        <source>Process timedout</source>
        <translation>Il processo non è terminato entro il tempo limite</translation>
    </message>
    <message>
        <source>Error while trying to write to process</source>
        <translation>Errore durante la scrittura nel processo</translation>
    </message>
    <message>
        <source>Error while trying to read from process</source>
        <translation>Errore durante la lettura dal processo</translation>
    </message>
    <message>
        <source>Unknown process error</source>
        <translation>Errore sconosciuto nel processo</translation>
    </message>
    <message>
        <source> ... Process GPSBabel</source>
        <translation>... processo GPSBabel</translation>
    </message>
    <message>
        <source>Stop Process</source>
        <translation>Arresta il processo</translation>
    </message>
    <message>
        <source>Process did not terminate successfully</source>
        <translation>Il processo non è terminato correttamente</translation>
    </message>
    <message>
        <source>Process crashed whle running</source>
        <translation>Il processo si è interrotto</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error processing formats from running process &quot;gpsbabel -^3&quot; at line %1</source>
        <translation>Si è verificato un errore durante l&apos;elaborazione dei formati da parte del processo di lavoro &quot;gpsbabel -^3&quot; alla linea %1</translation>
    </message>
</context>
<context>
    <name>RtTrkWidget</name>
    <message>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <source>Simplify routes and tracks by removing points</source>
        <translation>Semplifica rotte e tracce mediante rimozione di punti</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The Simplify filter is used to simplify routes and tracks for use with formats that limit the number of points they can contain or just to reduce the complexity of a route. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The filter attempts to remove points from each route until the number of points or the error is within the given bounds, while also attempting to preserve the shape of the original route as much as possible. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The quality of the results will vary depending on the density of points in the original route and the length of the original route. &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;margin-top:12px;margin-bottom:12px;margin-left:0px;margin-right:0px;-qt-block-indent:0;text-indent:0px;&quot;&gt;Il filtro di semplificazione viene usato per semplificare rotte e tracce per l&apos;uso con formati che supportano un limitato numero di punti o semplicemente per ridurre la complessit&amp;agrave; di una rotta.&lt;/p&gt;
&lt;p style=&quot;margin-top:12px;margin-bottom:12px;margin-left:0px;margin-right:0px;-qt-block-indent:0;text-indent:0px;&quot;&gt;Il filtro prova a rimuovere i punti da ogni rotta finch&amp;acute; il numero di punti o l&apos;errore ricade entro i limiti forniti, cercando nel contempo di mantenere per quanto possibile la forma della rotta originale.&lt;/p&gt;
&lt;p style=&quot;margin-top:12px;margin-bottom:12px;margin-left:0px;margin-right:0px;-qt-block-indent:0;text-indent:0px;&quot;&gt;La qualit&amp;agrave; dei risultati dipender&amp;agrave; dalla densit&amp;agrave; dei punti e dalla lunghezza della rotta originale.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty;margin-top:0px;margin-bottom:0px;margin-left:0px;margin-right:0px;-qt-block-indent:0;text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Routes &amp; Tracks</source>
        <translation>Rotte e tracce</translation>
    </message>
    <message>
        <source>Simplify route by removing points</source>
        <translation>Semplifica la rotta mediante la rimozione di punti</translation>
    </message>
    <message>
        <source> The Simplify filter is used to simplify routes and tracks for use with formats that limit the number of points they can contain or just to reduce the complexity of a route.

The filter attempts to remove points from each route until the number of points or the error is within the given bounds, while also attempting to preserve the shape of the original route as much as possible.

The quality of the results will vary depending on the density of points in the original route and the length of the original route. </source>
        <translation> Il filtro di semplificazione viene usato per semplificare rotte e tracce per l&apos;uso con formati che supportano un limitato numero di punti o semplicemente per ridurre la complessità di una rotta.

Il filtro prova a rimuovere i punti da ogni rotta finché il numero di punti o l&apos;errore ricade entro i limiti forniti, cercando nel contempo di mantenere per quanto possibile la forma della rotta originale.

La qualità dei risultati dipenderà dalla densità dei punti e dalla lunghezza della rotta originale. </translation>
    </message>
    <message>
        <source>Simplify</source>
        <translation>Semplifica</translation>
    </message>
    <message>
        <source>Limit To</source>
        <translation>Limita a</translation>
    </message>
    <message>
        <source>Maximum number points in track or route. </source>
        <translation>Numero massimo di punti nella traccia o rotta. </translation>
    </message>
    <message>
        <source>Points</source>
        <translation>Punti</translation>
    </message>
    <message>
        <source>Reverse tracks and routes</source>
        <translation>Inverti e rotte</translation>
    </message>
    <message>
        <source>The reversal is performed in the laziest way possible. Timestamps are kept with the original waypoints so the resulting track or route will have the interesting characteristic that time runs backwards. This tends to make Magellan Mapsend, in particular, do a wierd thing and place each waypoint on a separate day. 
Additionally, if you&apos;re using this to reverse a route that navigates, say, an exit ramp or a one way street, you will be in for unpleasant ride. application cares about timestamps </source>
        <translation>L&apos;inversione è effettuata nel modo più pigro possibile. Date ed ore sono mantenute con i punti di interesse originali in modo che la traccia o rotta risultante avrà la caratteristica interessante che il tempo scorre all&apos;indietro. Questo comporta, in particolare, che Magellan MapSend si comporti in modo strano e inserisca ogni punti di interesse in un giorno diverso.
Inoltre, se stai usando questa operazione per invertire una rotta che percorre, ad esempio, una rampa di uscita o una strada a senso unico, potrai incappare in un giro poco piacevoli. L&apos;applicazione si preoccupa di data e ora</translation>
    </message>
    <message>
        <source>Reverse</source>
        <translation>Inverti</translation>
    </message>
</context>
<context>
    <name>TrackWidget</name>
    <message>
        <source>Track Filter Options</source>
        <translation>Opzioni del filtro traccia</translation>
    </message>
    <message>
        <source>This filter performs various operations on track data. </source>
        <translation>Questo filtro esegue varie operazioni sui dati delle tracce.</translation>
    </message>
    <message>
        <source>Track Filters</source>
        <translation>Filtri delle tracce</translation>
    </message>
    <message>
        <source>Basic title for track</source>
        <translation>Titolo base della traccia</translation>
    </message>
    <message>
        <source>Basic title for new track(s). 
This option specifies a title for tracks generated by the track filter. By default, the title of the new track is composed of the start time of the track appended to this value. 
If this value contains a percent (%) character, it is treated as a format string for the POSIX strftime function, allowing custom time-based track names. </source>
        <translation>Titolo base per nuove tracce. 
Questa opzione specifica un titolo per le tracce generate dal filtro traccia. Come impostazione predefinita, il tutolo di una nuova traccia è composto dall&apos;ora di avvio della traccia aggiunto a questo valore. 
Se questo valore contiene un simbolo percentuale (%), questo viene trattato come stringa di formato per la funzione POSIX strftime, permettendo nomi di tracce personalizzati in base all&apos;ora. </translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <source>the title of the new track is composed of the start time of the track appended to this value. </source>
        <translation>il titolo della nuova traccia è composto dall&apos;ora di avvio della traccia aggiunto a questo valore. </translation>
    </message>
    <message>
        <source>Correct track point timestamps by specified amount</source>
        <translation>Correggi date ed ore dei punti traccia di un valore specifico</translation>
    </message>
    <message>
        <source>Correct trackpoint timestamps by a delta. 
This option changes the time of all trackpoints. This might be useful if your track must be moved by one or more hours because of an incorrect time zone. </source>
        <translation>Corregge date e ore dei punti traccia aggiungento /sottraendo un certo valore. 
Questa opzione modifica la data/l&apos;ora di tutti i punti traccia. Può essere utile se la tua traccia deve essere spostata di una o più ore per un&apos;impostazione errata del fuso orario. </translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Sposta</translation>
    </message>
    <message>
        <source>days</source>
        <translation>giorni</translation>
    </message>
    <message>
        <source>hours</source>
        <translation>ore</translation>
    </message>
    <message>
        <source>mins</source>
        <translation>minuti</translation>
    </message>
    <message>
        <source>secs</source>
        <translation>secondi</translation>
    </message>
    <message>
        <source>Use track pts. after this time. </source>
        <translation>Usa i punti traccia dopo quest&apos;ora. </translation>
    </message>
    <message>
        <source>Use only track points after this timestamp.

This option is used along with the stop to discard trackpoints that were recorded outside of a specific period of time. This option specifies the beginning of the time period. </source>
        <translation>Usa solo i punti traccia successivi a questa data/ora.

Questa opzione viene usata congiuntamente con lo stop per scartare i punti traccia che sono stati salvati al di fuori di uno specifico intervallo temporale. Questa opzione specifica l&apos;inizio dell&apos;intervallo temporale.</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inizio</translation>
    </message>
    <message>
        <source>If checked, time specified here is based on this computer&apos;s current time zone. </source>
        <translation>Se selezionato, l&apos;ora indicata qui è basata sul fuso orario impostato nel PC. </translation>
    </message>
    <message>
        <source>If checked, the times specified here are based on the local computer&apos;s time zone.  Otherwise it is UTC.</source>
        <translation>Se selezionato, gli orari specificati qui sono basati sul fuso orario del computer.  Altrimenti saranno in UTC (fuso di Greenwich).</translation>
    </message>
    <message>
        <source>Local Time</source>
        <translation>Tempo locale</translation>
    </message>
    <message>
        <source>Use track pts before this time. </source>
        <translation>Usa i punti traccia prima di quest&apos;ora. </translation>
    </message>
    <message>
        <source> Use only track points before this timestamp.

This option is used in conjunction with the start option to discard all trackpoints outside of a given period of time. This option defines the end of the time period. </source>
        <translation>Usa solo i punti traccia precedenti a questa data/ora.

Questa opzione viene usata congiuntamente con l&apos;inizio per scartare i punti traccia che sono stati salvati al di fuori di uno specifico intervallo temporale. Questa opzione specifica la fine dell&apos;intervallo temporale. </translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Fine</translation>
    </message>
    <message>
        <source>Pack all tracks into one. </source>
        <translation>Concatena tutte le tracce in una. </translation>
    </message>
    <message>
        <source>Pack all tracks into one.

This option causes all tracks to be appended to one another to form a single track. This option does not work if any two tracks overlap in time; in that case, consider using the merge option.

This option is most useful for rejoining tracks that might have been interrupted by an equipment malfunction or an overnight stop. </source>
        <translation>Concatena tutte le tracce in una.

Questa opzione fa in modo che tutte le tracce vengano unite per formarne una sola. Questa opzione non funziona se due tracce si sovrappongono temporalmente: in quel caso prova ad utilizzare l&apos;opzione unisci.

Questa opzione è utile soprattutto per unire tracce che si sono interrotte per un malfunzionamento del dispositivo o per un arresto notturno. </translation>
    </message>
    <message>
        <source>Pack</source>
        <translation>Concatena</translation>
    </message>
    <message>
        <source>Merge multiple tracks for the same way.</source>
        <translation>Unisci più tracce per la stessa strada.</translation>
    </message>
    <message>
        <source> Merge multiple tracks for the same way.

This option puts all track points from all tracks into a single track and sorts them by time stamp. Points with identical time stamps will be dropped. </source>
        <translation> Unisce più tracce per la stessa strada.

Questa opzione inserisce tutti i punti di ogni traccia in una singola traccia e li ordina in base all&apos;orario. I punti con lo stesso orario saranno tralasciati. </translation>
    </message>
    <message>
        <source>Merge</source>
        <translation>Unisci</translation>
    </message>
    <message>
        <source>Split by Date</source>
        <translation>Suddividi per data</translation>
    </message>
    <message>
        <source>Split by Time</source>
        <translation>Suddividi per ora</translation>
    </message>
    <message>
        <source>If nonzero, the track will be split if the time between two points is greater than this parameter.   If zero, the track will be split by date. </source>
        <translation>Se diverso da zero, la traccia verrà suddivisa se il tempo tra due punti è maggiore di questo parametro.   Se zero, la traccia verrà suddivisa in base al giorno. </translation>
    </message>
    <message>
        <source>hrs</source>
        <translation>ore</translation>
    </message>
    <message>
        <source>Split by Dist.</source>
        <translation>Suddividi per distanza</translation>
    </message>
    <message>
        <source>If nonzero, the input track will be split into several tracks if the distance between successive track points is greater than the distance given as a parameter. </source>
        <translation>Se non zero, la traccia in ingresso verrà suddivisa in più tracce se la distanza tra punti traccia successivi è maggiore della distanza specificata nel parametro. </translation>
    </message>
    <message>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <source>GPS Fixes</source>
        <translation>Stato del GPS</translation>
    </message>
    <message>
        <source>none</source>
        <translation>nessuno</translation>
    </message>
    <message>
        <source>pps</source>
        <translation>pps</translation>
    </message>
    <message>
        <source>dgps</source>
        <translation>dgps</translation>
    </message>
    <message>
        <source>3d</source>
        <translation>3d</translation>
    </message>
    <message>
        <source>2d</source>
        <translation>2d</translation>
    </message>
    <message>
        <source>Synthesize speed. </source>
        <translation>Sintetizza la velocità. </translation>
    </message>
    <message>
        <source>Synthesize speed.

This option computes a value for the GPS speed at each trackpoint. This is most useful with trackpoints from formats that don&apos;t support speed information or for trackoints synthesized by the interpolate filter. The speed at each trackpoint is the average speed from the previous trackpoint (distance divided by time). The first trackpoint in each track is assigned a speed of &quot;unknown.&quot; </source>
        <translation>Sintetizza la velocità.

Questa opzione calcola il valore della velocità GPS in ogni punto traccia. Risulta utile soprattutto con punti traccia tratti da un formato che non specifica informazioni sulla velocità o da punti traccia sintetizzati dal filtro di interpolazione. La velocità in ogni punto traccia è la velocità media calcolata dal punto precedente (distanza diviso il tempo). Al primo punto di ogni traccia viene assegnata una velocità &quot;sconosciuta.&quot; </translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocità</translation>
    </message>
    <message>
        <source>Synthesize course.</source>
        <translation>Sintetizza la direzione.</translation>
    </message>
    <message>
        <source>Synthesize course.

This option computes (or recomputes) a value for the GPS heading at each trackpoint. This is most useful with trackpoints from formats that don&apos;t support heading information or for trackpoints synthesized by the interpolate filter. The heading at each trackpoint is simply the course from the previous trackpoint in the track. The first trackpoint in each track is arbitrarily assigned a heading of 0 degrees. </source>
        <translation>Sintetizza la direzione.

Questa opzione calcola (o ricalcola) un valore per la direzione del GPS in ogni punto traccia. Risulta utile soprattutto con punti traccia tratti da un formato che non specifica informazioni sulla direzione o da punti traccia sintetizzati dal filtro di interpolazione. La direzione in ogni punto traccia è tratta semplicemente dalla posizione del punto traccia precedente nella traccia stessa. Al primo punto di ogni traccia viene arbitrariamente assegnato un valore pari a 0 gradi. </translation>
    </message>
    <message>
        <source>Course</source>
        <translation>Direzione</translation>
    </message>
</context>
<context>
    <name>Upgrade</name>
    <message>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
</context>
<context>
    <name>UpgradeCheck</name>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Download failed: %1.</source>
        <translation>Scaricamento non riuscito: %1.</translation>
    </message>
    <message>
        <source>A new version of GPSBabel is available.&lt;br /&gt;Your version is %1 &lt;br /&gt;The latest version is %2</source>
        <translation>È disponibile una nuova versione di GPSBabel.&lt;br /&gt;Versione corrente: %1 &lt;br /&gt;Nuova versione: %2</translation>
    </message>
    <message>
        <source>Upgrade</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>Do you wish to download an upgrade?</source>
        <translation>Si desidera scaricare un aggiornamento?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Invalid return data at line %1: %2.</source>
        <translation>Dati ricevuti non validi alla linea %1: %2.</translation>
    </message>
</context>
<context>
    <name>WayPtsWidget</name>
    <message>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <source>Waypoints Filters</source>
        <translation>Filtri dei punti di interesse</translation>
    </message>
    <message>
        <source>Remove duplicates</source>
        <translation>Rimuovi i duplicati</translation>
    </message>
    <message>
        <source>The duplicate filter is designed to remove duplicate points based on their short name (traditionally a waypoint&apos;s name on the GPS receiver), and/or their location (to a precision of 6 decimals). This filter supports two options that specify how duplicates will be recognized, shortname and location. Generally, at least one of these options is required. </source>
        <translation>Il filtro dei duplicati è studiato per rimuovere i punti duplicati in base al loro nome breve (tipicamente un nome del punto di interesse sul ricevitore GPS), e/o in base alla posizione (con una precisione di 6 decimali). Questo filtro supporta due opzioni che indicano come individuare i duplicati, nome breve e posizione. In genere è necessario specificare almeno una di queste opzioni. </translation>
    </message>
    <message>
        <source>Duplicates</source>
        <translation>Duplicati</translation>
    </message>
    <message>
        <source>Suppress duplicate waypoints based on name.</source>
        <translation>Rimuovi i punti di interesse in base al nome.</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suppress duplicate waypoints based on name. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This option is the one most often used with the duplicate filter. This option instructs the duplicate filter to remove any waypoints that share a short name with a waypoint that has come before. This option might be used to remove duplicates if you are merging two datasets that were each created in part from a common ancestor dataset. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Rimuovi i punti di interesse in base al nome. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Questa opzione è la più usata col filtro dei duplicati. Indica al filtro dei duplicaati di rimuovere qualsiasi punto di interesse con un nome breve condiviso con un puntio di interesse già analizzato. Questa opzione può essere usata per rimuovere i duplicati se stai unendo due serie di dati che sono state create partendo dalla stessa una serie di dati iniziale. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Short Names</source>
        <translation>Nomi brevi</translation>
    </message>
    <message>
        <source>Suppress duplicate waypoint based on coords. </source>
        <translation>Rimuovi i punti di interesse in base alle coordinate. </translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suppress duplicate waypoint based on coords. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This option causes the duplicate filter to remove any additional waypoint that has the same coordinates (to six decimal degrees) as a waypoint that came before. This option may be used to remove duplicate waypoints if the names are not expected to be the same. It also might be used along with the &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;shortname&lt;/span&gt; option to remove duplicate waypoints if the names of several unrelated groups of waypoints might be the same. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Rimuovi i punti di interesse in base alle coordinate. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Questa opzione fa sì che il filtro dei duplicati rimuova ogni ulteriore punto di interesse avente le stesse coordinate (con una precisione di sei cifre decimali). Questa opzione può essere usata per rimuovere punti di interesse duplicati anche quando i nomi non coincidono. Puà essere usata anche congiuntamente all&apos;opzione &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;bomi brevi&lt;/span&gt; per rimuovere punti di interesse se i nomi di diversi gruppi indipendenti di punti di interesse potrebbero coincidere. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Locations</source>
        <translation>Posizioni</translation>
    </message>
    <message>
        <source>Remove points based on proximity</source>
        <translation>Rimuovi i punti in base alla vicinanza</translation>
    </message>
    <message>
        <source>Maximum positional distance.

This option specifies the minimum allowable distance between two points. If two points are closer than this distance, only one of them is kept. </source>
        <translation>Massima distanza di posizione.

Questa opzione specifica la distanza minima consentita tra due punti. Se due punti sono più vicini di questa distanza, solo uno di essi viene mantenuto. </translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <source>Maximum positional distance.</source>
        <translation>Massima distanza di posizione.</translation>
    </message>
    <message>
        <source>Feet</source>
        <translation>Piedi</translation>
    </message>
    <message>
        <source>Meters</source>
        <translation>Metri</translation>
    </message>
    <message>
        <source>Include points only within radius</source>
        <translation>Includi punto solo entro una distanza</translation>
    </message>
    <message>
        <source>This filter includes or excludes waypoints based on their proximity to a central point. All waypoints more than the specified distance from the specified point will be removed from the dataset.

By default, all remaining points are sorted so that points closer to the center appear earlier in the output file. </source>
        <translation>Questo filtro include o esclude i punti di interesse in funzione della loro distanza da un punto centrale. Tutti i punti di interesse con una distanza superiore a quella indicata dal punto specificato saranno rimossi dalla serie di dati.

Per impostazione predefinita, tutti gli altri punti sono ordinati in modo che i punti più vicini al centro vengano prima nel file di destinazione.</translation>
    </message>
    <message>
        <source>Radius</source>
        <translation>Raggio</translation>
    </message>
    <message>
        <source>Maximum distance from center. </source>
        <translation>Distanza massima dal centro.</translation>
    </message>
    <message>
        <source>Miles</source>
        <translation>Miglia</translation>
    </message>
    <message>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <source>Lat.</source>
        <translation>Lat.</translation>
    </message>
    <message>
        <source>Latitude of the central point in decimal degrees.  South latitudes should be expressed as a negative number.</source>
        <translation>Latitudine del punto centrale in gradi decimali. Le latitudini dell&apos;emisfero sud vanno inserite come un numero negativo.</translation>
    </message>
    <message>
        <source>Long.</source>
        <translation>Long.</translation>
    </message>
    <message>
        <source>Longitude of the central point in decimal degrees. West longitudes should be expressed as a negative number.</source>
        <translation>Longitudine del punto centrale in gradi decimali. Le latitudini dell&apos;emisfero occidentale vanno inserite come un numero negativo.</translation>
    </message>
    <message>
        <source>This filter sorts waypoints into alphabetical order</source>
        <translation>Questo filtro ordina i punti di interesse in ordine alfabetico</translation>
    </message>
    <message>
        <source>Sort</source>
        <translation>Ordina</translation>
    </message>
</context>
</TS>
